@@ -20,9 +20,9 @@
 #' are fairly well concentrated around the vectors \eqn{\mu_j} of each cluster;
 #' (3) the percentage of noise in the data increases.
 #' 
-#' @param dat Data matrix or data.frame of data points on the sphere to be 
-#'            clustered. The observations in \code{dat} are normalized by 
-#'            dividing with the length of the vector to ensure
+#' @param dat \eqn{(n \times d)}-data matrix or data.frame of data points on the
+#'             sphere to be clustered. The observations in \code{dat} are 
+#'             normalized by dividing with the length of the vector to ensure
 #'            that they lie on the \eqn{d}-dimensional sphere. Note that 
 #'            \eqn{d > 1}.
 #' @param nClust Number of clusters. It can be a single value or a numeric 
@@ -68,7 +68,7 @@
 #' \eqn{\mathcal{S}^{d-1}}, but it can also be performed on spherically
 #' transformed observations, i.e. data points on the Euclidean space 
 #' \eqn{\mathbb{R}^d} that are normalized such that they lie on the 
-#' corresponding \eqn{d}-dimensional sphere \eqn{\mathcal{S}^{d-1}}.
+#' corresponding \eqn{(d-1)}-dimensional sphere \eqn{\mathcal{S}^{d-1}}.
 #'
 #' @return An S4 object of class \code{pkbc} containing the results of the 
 #' clustering procedure based on Poisson kernel-based distributions. The object 
@@ -105,19 +105,19 @@
 #' DOI: 10.1080/10618600.2020.1740713.
 #'
 #' @examples
-#' #We generate three samples of 100 observations from 3-dimensional
-#' #Poisson kernel-based densities with rho=0.8 and different mean directions
-#' size<-100
-#' groups<-c(rep(1, size), rep(2, size),rep(3,size))
-#' rho<-0.8
+#' # We generate three samples of 100 observations from 3-dimensional
+#' # Poisson kernel-based densities with rho=0.8 and different mean directions
+#' size <- 100
+#' groups <- c(rep(1, size), rep(2, size), rep(3, size))
+#' rho <- 0.8
 #' set.seed(081423)
-#' data1<-rpkb(size, c(1,0,0),rho)
-#' data2<-rpkb(size, c(0,1,0),rho)
-#' data3<-rpkb(size, c(0,0,1),rho)
-#' dat<-rbind(data1$x,data2$x, data3$x)
+#' data1 <- rpkb(size, c(1, 0, 0), rho)
+#' data2 <- rpkb(size, c(0, 1, 0), rho)
+#' data3 <- rpkb(size, c(0, 0, 1), rho)
+#' dat <- rbind(data1, data2, data3)
 #'
-#' #Perform the clustering algorithm with number of clusters k=3.
-#' pkbd<- pkbc(dat=dat, nClust=3)
+#' # Perform the clustering algorithm with number of clusters k=3.
+#' pkbd <- pkbc(dat = dat, nClust = 3)
 #' show(pkbd)
 #'
 #' @srrstats {G2.0a} Documentation of input nClust
@@ -130,14 +130,12 @@
 #' 
 #' @export
 setGeneric("pkbc",function(dat, 
-                           nClust = NULL,
+                           nClust,
                            maxIter = 300,
                            stoppingRule = "loglik",
                            initMethod = "sampleData",
-                           numInit = 10){
-   
-   standardGeneric("pkbc")
-})
+                           numInit = 10)
+   standardGeneric("pkbc"))
 #' @rdname pkbc
 #' 
 #' @srrstats {G2.0} input nClust
@@ -145,7 +143,6 @@ setGeneric("pkbc",function(dat,
 #' @srrstats {G2.13,G2.14,G2.14a,G2.15,G2.16} error for NA, Nan, Inf, -Inf
 #' 
 #' @srrstats {UL2.1} normalization of input dat
-#' @srrstats {UL2.3} inputs are all checked
 #' @srrstats {UL7.0} error messages are inserted for inappropriate inputs
 #' 
 #' @importFrom methods new
@@ -155,7 +152,7 @@ setGeneric("pkbc",function(dat,
 #' @export
 setMethod("pkbc", signature(dat = "ANY"),
     function(dat,
-             nClust = NULL,
+             nClust,
              maxIter = 300,
              stoppingRule = "loglik",
              initMethod = "sampleData",
@@ -174,11 +171,15 @@ setMethod("pkbc", signature(dat = "ANY"),
                   greater than 0')
           }
        } else {
-          stop("nClust must be a signle value or a numeric vector of possible
+          stop("nClust must be a single value or a numeric vector of possible
                   values")
        }
-       if (maxIter < 1) {
-          stop("Input parameter maxIter must be greater than 0")
+       if(is.vector(maxIter) & is.numeric(maxIter)) {
+          if (maxIter < 1) {
+             stop("Input parameter maxIter must be an integer greater than 0.")
+          }
+       } else {
+          stop("maxIter must be a single integer value.") 
        }
        if ( !(stoppingRule %in% c("max", "membership", "loglik")) ) {
           stop(paste("Unrecognized value ", stoppingRule, " in input 
@@ -188,8 +189,12 @@ setMethod("pkbc", signature(dat = "ANY"),
           stop(paste("Unrecognized value ", initMethod, " in input 
           parameter initMethod.", sep=''))
        }
-       if (numInit < 1) {
-          stop("Input parameter numInit must be greater than 0")
+       if(is.vector(numInit) & is.numeric(numInit)) {
+          if (numInit < 1) {
+             stop("Input parameter numInit must be greater than 0.")
+          }
+       } else {
+          stop("numInit must be a single integer value.")
        }
        
        # set options for stopping rule
@@ -468,8 +473,8 @@ setMethod("show", "pkbc", function(object) {
 #'         with a table with the assigned memberships.
 #' 
 #' @examples
-#' dat <- rbind(matrix(rnorm(100),2),matrix(rnorm(100,5),2))
-#' res <- pkbc(dat,2:4)
+#' dat <- rbind(matrix(rnorm(100), 2), matrix(rnorm(100, 5), 2))
+#' res <- pkbc(dat, 2:4)
 #' summary(res)
 #' 
 #' @seealso [pkbc()] for the clustering algorithm \cr
@@ -490,8 +495,9 @@ setMethod("summary", "pkbc", function(object) {
             function(res) {
                c(LogLik = res$LogLik, wcss = sum(res$wcss))
             }))
+   summaryMatrix <- cbind(object@input$nClust, summaryMatrix)
    rownames(summaryMatrix) <- names(object@res_k[object@input$nClust])
-   colnames(summaryMatrix) <- c("LogLik", "WCSS")
+   colnames(summaryMatrix) <- c("nClust", "LogLik", "WCSS")
    cat("Summary:\n")
    print(summaryMatrix)
    cat("\n")
@@ -528,7 +534,7 @@ setMethod("summary", "pkbc", function(object) {
 #'          \linkS4class{pkbc} for the class object definition.
 #'          
 #' @export
-setGeneric("stats_clusters",function(object,...){
+setGeneric("stats_clusters",function(object,...) {
    
    standardGeneric("stats_clusters")
 })
@@ -560,7 +566,6 @@ setGeneric("stats_clusters",function(object,...){
 #'
 #'
 #' @srrstats {G1.4} roxigen2 is used
-#' @srrstats {UL3.2} true label can be provided as a separate input
 #' @srrstats {UL3.4} the function computes summary statistics with respect to 
 #'                   the identified clusters.
 #'                   
@@ -572,11 +577,11 @@ setGeneric("stats_clusters",function(object,...){
 #' @rdname stats_clusters 
 #' @aliases stats_clusters,pkbc-method                 
 #' @export
-setMethod("stats_clusters", "pkbc", function(object, k){
+setMethod("stats_clusters", "pkbc", function(object, k) {
    
-   if(!(is.numeric(k) & length(k)==1)){
+   if(!(is.numeric(k) & length(k)==1)) {
       stop("k must be an integer")
-   } else if(!(k %in% object@input$nClust)){
+   } else if(!(k %in% object@input$nClust)) {
       stop("The provided pkbc object does not contain results for the requested
            number of clusters")
    } 
@@ -586,7 +591,7 @@ setMethod("stats_clusters", "pkbc", function(object, k){
    
    metrics <- list()
    
-   for(i in seq_len(ncol(x))){
+   for(i in seq_len(ncol(x))) {
       res <- rbind(as.numeric(by(x[,i],y,mean)),
                    as.numeric(by(x[,i],y,sd)),
                    as.numeric(by(x[,i],y,median)),
@@ -644,8 +649,8 @@ setMethod("stats_clusters", "pkbc", function(object, k){
 #'          \linkS4class{pkbc} for the class object definition.
 #' 
 #' @examples
-#' dat<-matrix(rnorm(300),ncol=3)
-#' pkbc_res<- pkbc(dat, 3)
+#' dat <- matrix(rnorm(300), ncol = 3)
+#' pkbc_res <- pkbc(dat, 3)
 #' plot(pkbc_res, 3)
 #' 
 #' @references
@@ -653,7 +658,7 @@ setMethod("stats_clusters", "pkbc", function(object, k){
 #' component analysis for functional data." Test 8, 1–73. 
 #' https://doi.org/10.1007/BF02595862
 #' 
-#' 
+#' @srrstats {UL3.2} true label can be provided as a separate input
 #' @srrstats {UL6.1} this function includes a plot method
 #' @srrstats {UL6.0,UL6.2} plot method for pkbc object
 #' 
@@ -706,10 +711,10 @@ setMethod("plot", c(x = "pkbc"),
 #' @importFrom grDevices rainbow
 #' @importFrom graphics legend
 #' @importFrom graphics par
-#' @import ggplot2
+#' @importFrom ggplot2 ggplot geom_point theme_minimal labs theme
 #' @importFrom rrcov PcaLocantore
 #' 
-#' @srrstats {G1.4} roxigen2 is used
+#' @srrstats {G1.4} roxygen2 is used
 #' 
 #' @keywords internal
 #' @noRd
@@ -831,18 +836,18 @@ scatterplotMethod <- function(object, k, true_label = NULL, pca_res = FALSE) {
 #'         within sum of squares computed with the Euclidean distance and the 
 #'         cosine similarity.
 #' 
-#' @import ggplot2
+#' @importFrom ggplot2 ggplot geom_line geom_point labs theme_minimal
 #' @importFrom ggpubr ggarrange
 #' 
-#' @srrstats {G1.4} roxigen2 is used
+#' @srrstats {G1.4} roxygen2 is used
 #' 
 #' @keywords internal
 #' @noRd
-elbowMethod <- function(object){
+elbowMethod <- function(object) {
    
    wcss <- matrix(ncol=2)
    
-   for(k in object@input$nClust){
+   for(k in object@input$nClust) {
       wcss <- rbind(wcss, object@res_k[[k]]$wcss)
    }
    wcss <- wcss[-1,]
@@ -893,14 +898,14 @@ elbowMethod <- function(object){
 #' 
 #' @examples
 #' # generate data
-#' dat <- rbind(matrix(rnorm(100),ncol=2),matrix(rnorm(100,5),ncol=2))
-#' res <- pkbc(dat,2)
+#' dat <- rbind(matrix(rnorm(100), ncol = 2), matrix(rnorm(100, 5), ncol = 2))
+#' res <- pkbc(dat, 2)
 #' 
 #' # extract membership of dat
-#' predict(res,k=2)
+#' predict(res, k = 2)
 #' # predict membership of new data
-#' newdat <- rbind(matrix(rnorm(10),ncol=2),matrix(rnorm(10,5),ncol=2))
-#' predict(res, k=2, newdat)
+#' newdat <- rbind(matrix(rnorm(10), ncol = 2), matrix(rnorm(10, 5), ncol = 2))
+#' predict(res, k = 2, newdat)
 #'  
 #' @seealso [pkbc()] for the clustering algorithm \cr
 #'          \linkS4class{pkbc} for the class object definition.
@@ -1008,10 +1013,12 @@ setMethod("predict", signature(object="pkbc"),
 #' between the partitions and a value close to 0 indicates a random assignment 
 #' of data points to clusters.
 #' 
-#' Each cluster can represented by a so-called silhouette which is based on the
-#' comparison of its tightness and separation. The average silhouette width 
-#' provides an evaluation of clustering validity, and might be used to select 
-#' an *appropriate* number of clusters (Rousseeuw 1987). 
+#' The average silhouette width quantifies the quality of clustering by 
+#' measuring how well each object fits within its assigned cluster. It is the 
+#' mean of silhouette values, which compare the tightness of an object within 
+#' its cluster to its separation from other clusters. Higher values indicate 
+#' well-separated, cohesive clusters, making it useful for selecting the 
+#' *appropriate* number of clusters (Rousseeuw 1987). 
 #' 
 #' Macro Precision is a metric used in multi-class classification that 
 #' calculates the precision for each class independently and then takes the 
@@ -1045,8 +1052,8 @@ setMethod("predict", signature(object="pkbc"),
 #'          \linkS4class{pkbc} for the class object definition.
 #'
 #' @references
-#' Kapp, A.V. and Tibshirani, R. (2007) "Are clusters found in one dataset present 
-#' in another dataset?", Biostatistics, 8(1), 9–31, 
+#' Kapp, A.V. and Tibshirani, R. (2007) "Are clusters found in one dataset 
+#' present in another dataset?", Biostatistics, 8(1), 9–31, 
 #' https://doi.org/10.1093/biostatistics/kxj029
 #' 
 #' Rousseeuw, P.J. (1987) Silhouettes: A graphical aid to the interpretation and
@@ -1060,17 +1067,17 @@ setMethod("predict", signature(object="pkbc"),
 #' #We generate three samples of 100 observations from 3-dimensional
 #' #Poisson kernel-based densities with rho=0.8 and different mean directions
 #' 
-#' size<-20
-#' groups<-c(rep(1, size), rep(2, size),rep(3,size))
-#' rho<-0.8
+#' size <- 20
+#' groups <- c(rep(1, size), rep(2, size), rep(3, size))
+#' rho <- 0.8
 #' set.seed(081423)
-#' data1<-rpkb(size, c(1,0,0),rho,method='rejvmf')
-#' data2<-rpkb(size, c(0,1,0),rho,method='rejvmf')
-#' data3<-rpkb(size, c(1,0,0),rho,method='rejvmf')
-#' data<-rbind(data1$x,data2$x, data3$x)
+#' data1 <- rpkb(size, c(1,0,0), rho, method = 'rejvmf')
+#' data2 <- rpkb(size, c(0,1,0), rho, method = 'rejvmf')
+#' data3 <- rpkb(size, c(1,0,0), rho, method = 'rejvmf')
+#' data <- rbind(data1, data2, data3)
 #'
 #' #Perform the clustering algorithm
-#' pkbc_res<- pkbc(data, 3)
+#' pkbc_res <- pkbc(data, 3)
 #' pkbc_validation(pkbc_res)
 #' 
 #' 
@@ -1079,7 +1086,7 @@ setMethod("predict", signature(object="pkbc"),
 #' @srrstats {UL3.2} true label can be provided as a separate input 
 #' 
 #' @export
-pkbc_validation <- function(object, true_label=NULL){
+pkbc_validation <- function(object, true_label=NULL) {
    
    # nocov start
    if (!requireNamespace("mclust", quietly = TRUE)) {
